# DustyDisk
```DustyDisk``` is a python package created during the code/astro 2025 workshop at Northwestern University (CIERA). 

Authors: SM Gopika & Miranda Pikus. Affiliation: Department of Physics and Astronomy at Purdue University

The ```DustyDisk``` package serves as an aide to model and visualize the hydrodynamical behavior of dust in astrophysical disks, particularly for the application of planetary formation. It acts as a simple package that models where dust would be trapped in the disk. Using hydrodynamic principles, ```DustyDisk``` takes in system parameters such as the temperature and gas density profile for a disk system, then computes and visualizes the dust properties and distribution.

Check out our tutorial jupyter notebook in ```examples/ExampleTutorial.ipynb``` to get started. Further documentation can be found here: https://dustydisk.readthedocs.io

Be sure to run our test suite in ```tests/``` to make sure there are no problems with the code version you are working with.

[![A rectangular badge, half black half purple containing the text made at Code Astro](https://img.shields.io/badge/Made%20at-Code/Astro-blueviolet.svg)](https://semaphorep.github.io/codeastro/)
